function [abc, pqr]=abcfixed(E,L,FP);
// abcfixed Calculate the initial ANFIS model parameters.
//
//    ANFISLAB: Toolbox de ANFIS (ADAPTATIVE-NETWORK-BASED-FUZZY INFERENCE SYSTEM) para SCILAB
//    Creado Por Andres G. Avendaño Cabezas., Universidad Central de Venezuela (andrewg.avendano@gmail.com),
//    Agosto de 2009, con adaptaciones del codigo ANFIS de dominio publico de Jyh-shing Roger Jang
//    (http://www.cs.nthu.edu.tw/~jang/publication.htm) y FISLAB de G. Ortega.
//    Este programa fue probado en SCILAB version 5.1.1, PC Intel Core(TM) Duo 2,1Ghz, corriendo Linux 2.6.27.7.
//    
//    The program was made to be "atom competible" by Tan C.L.
//    It also modified to work seamlessly with sciFLT to provide more
//    powerful tools for neuro-fuzzy domain. 
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 2 of the License, or
//    (at your option) any later version.
//    
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//    
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/
//
// Calling Sequence
//     abc = abcfixed(E,L,FP);
//     [abc, pqr]=abcfixed(E,L,FP);
//
// Parameters
//     E : Training data, each variables arranged in a column, with last column as the output varaible
//     L : Number of membership functions per input variable
//     FP : Membership function, 'gbellmf', 'trimf' or 'trapmf'
//     abc : ANFIS model parameters, input membership functions
//     pqr : ANFIS model parameters, output rules parameters
//
// Description
//    This function calculate the initial ANFIS model parameters, each row representing one membership function. Total number of rows is the number of input variables mutiply by the number of membership functions per input variable. 
//    
// Examples
//    x = (0:0.1:10)';
//    y = sin(2*x)./exp(x/5);
//    abc=abcfixed([x y],5,'trapmf')
// 
// See also
//
// Authors
//     Andres G. Avendaño Cabezas, Jyh-shing Roger Jang, Tan C.L. 


rhs=argn(2);

// Error Checking
if rhs < 1; error("Expect at least 1 argument, traindata");end
if rhs < 2; L = 2; end
if rhs < 3; FP = 'gbellmf'; end

if type(FP) == 10 then   
    if strcmp(FP,'gbellmf','i')==0 then
        FP = 2;
    elseif strcmp(FP,'trapmf','i')==0 then
        FP = 3;
    elseif strcmp(FP,'trimf','i')==0 then
        FP = 4;
    else
        error("anfislab only support gbellmf, trimf, trapmf at the moment.");
    end
end

[p,ko]=size(E);
k=ko-1;
pqr=ones(L^k,(k+1));

//parámetros antecedentes
if FP==1 then
  for h=1:k
    if L==1 then 
      a(1,h)=max(E(:,h))*9999;
      c(1,h)=max(E(:,h));
    else
      pso(1,h)=(max(E(:,h))-min(E(:,h)))/(2*(L-1));
      c(:,h)=[min(E(:,h)):2*pso(1,h):max(E(:,h))]';
      a(1,h)=pso(1,h)*(1+0.0959573 );
    end;b=2;
  end
elseif FP==2 then
  for h=1:k
    if L==1 then 
      a(1,h)=max(E(:,h))*9999;
      c(1,h)=max(E(:,h));
    else
      a(1,h)=(max(E(:,h))-min(E(:,h)))/(2*(L-1));
      c(:,h)=[min(E(:,h)):2*a(1,h):max(E(:,h))]';
    end;b=2;
  end
elseif FP==3 then
  for h=1:k
    if L==1 then 
      b(1,h)=max(E(:,h))*9999;
      c(1,h)=max(E(:,h));
      a(1,h)=0;
    else
      pso(1,h)=(max(E(:,h))-min(E(:,h)))/(L-1);
      c(:,h)=[min(E(:,h)):pso(1,h):max(E(:,h))]';
      b(:,h)=pso(1,h)/2;
      a(:,h)=1/(pso(1,h)-b(:,h));
    end
  end
elseif FP==4 then
  for h=1:k
    if L==1 then 
      b(1,h)=max(E(:,h))*9999;
      c(1,h)=max(E(:,h));
      a(1,h)=0;
    else
      pso(1,h)=(max(E(:,h))-min(E(:,h)))/(L-1);
      c(:,h)=[min(E(:,h)):pso(1,h):max(E(:,h))]'; // mid point
      b(:,h)=0;
      a(:,h)=1/(pso(1,h));
      //b(:,h)=[min(E(:,h)):pso(1,h):max(E(:,h))]'; // mid point 
      //m(:,h)=1/(pso(1,h));
      //a(:,h)=b(:,h)-1/m(:,h);
      //c(:,h)=1/m(:,h)+b(:,h);
    end
  end
end
//pause
//ordena matriz inicial abc
n=0;s=0;
  for t=1:k
    for i=s+1:1:L*t
      n=n+1;
      if n==L+1 then n=1;end
        abc(i,1)=a(1,t);
      if FP==1|FP==2 then
        abc(i,2)=b;
      elseif FP==3
   	    abc(i,2)=b(1,t);
      elseif FP==4
        //abc(i,1)=a(n,t);
        //abc(i,2)=b(n,t);
        abc(i,2) = 0;
      end
      abc(i,3)=c(n,t);
      s=i;
    end
  end
endfunction
