function [abc,pqr]=fls2abcpqr(fls)
// fls2abcpqr Extract the membership functions from a ANFIS model for training purposes.
//
//    ANFISLAB: Toolbox de ANFIS (ADAPTATIVE-NETWORK-BASED-FUZZY INFERENCE SYSTEM) para SCILAB
//    Creado Por Andres G. Avendaño Cabezas., Universidad Central de Venezuela (andrewg.avendano@gmail.com),
//    Agosto de 2009, con adaptaciones del codigo ANFIS de dominio publico de Jyh-shing Roger Jang
//    (http://www.cs.nthu.edu.tw/~jang/publication.htm) y FISLAB de G. Ortega.
//    Este programa fue probado en SCILAB version 5.1.1, PC Intel Core(TM) Duo 2,1Ghz, corriendo Linux 2.6.27.7.
//    
//    The program was made to be "atom compatible" by Tan C.L.
//    It also modified to work seamlessly with sciFLT to provide more
//    powerful tools for neuro-fuzzy domain. 
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 2 of the License, or
//    (at your option) any later version.
//    
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//    
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <http://www.gnu.org/licenses/
//
// Calling Sequence
//     [abc,pqr]=fls2abcpqr(fls)
//
// Parameters
//     fls : ANFIS model (in format compatible with sciFLT)
//     abc : Input membership function parameters
//     pqr : Output membership function parameters
//
// Description
//    This function is only for expert/developer, who need to call the anfislab library directly.
// 
// Examples
//    x = (0:0.1:10)';
//    y = sin(2*x)./exp(x/5);
//    fls = initanfis([x y],5,'gbellmf');
//    [abc,pqr]=fls2abcpqr(fls);
// 
// See also
//    abc2par
//    fls2abcpqr
//
// Authors
//     Andres G. Avendaño Cabezas, Jyh-shing Roger Jang, Tan C.L.  
//

k = size(fls.input);
L = size(fls.input(1).mf);

for cnt_var = 1:k
    //flsvar.name = 'input'+string(cnt_var);
    //range_min = min(E(:,cnt_var));
    //range_max = max(E(:,cnt_var));
    //flsvar.range = [range_min range_max];
    //fls.input(cnt_var) = flsvar;
    // Creating nodes members
    for cnt_mf = 1:L
        par((cnt_var-1)*L+cnt_mf,:) = fls.input(cnt_var).mf(cnt_mf).par;
    end
end
    
abc = par2abc(par,fls.input(1).mf(1).type);

k = size(fls.output);
L = size(fls.output(1).mf);

clear par;
for cnt_var = 1:k
    //flsvar.name = 'input'+string(cnt_var);
    //range_min = min(E(:,cnt_var));
    //range_max = max(E(:,cnt_var));
    //flsvar.range = [range_min range_max];
    //fls.input(cnt_var) = flsvar;
    // Creating nodes members
    for cnt_mf = 1:L
        par((cnt_var-1)*L+cnt_mf,:) = fls.output(cnt_var).mf(cnt_mf).par;
    end
end

pqr = par;

    
endfunction
