function y = bell_1(x, a, b, c)

// BELL_1: Generalized bell-shaped membership function with  three 
//         parameters a, b, c. (Defaults are 1, 1, and 0 respectively).
//         
//                          Y=BELL_1(X, a, b, c)
//
//         Returns a matrix y with the same size as X; each element of 
//         Y is a grade of membership.Y=exp(-((((X -c)/a)^2)^b) );
//
// 	              See also BELL_2, SIGMOID, TRAPEZE and MF_PANEL.

// FISLAB: Fuzzy Inference Systems toolbox for SCILAB
// Created for MATLAB by 
//	(c) A. Lotfi, University of Queensland (Email: lotfia@s1.elec.uq.oz.au) 13-10-93
// Translated to SCILAB 
//	by G. Ortega, European Space Agency (Email: gortega@estec.esa.nl) 25-07-96
// The program has been tested on SCILAB version 2.2, PC Pentium, runing Linux 1.3.30

[nargout,nargin]=argn(0);
if nargin < 4 then c=0; end,
if nargin < 3 then b=1; end,
if nargin < 2 then a=1; end,
[m,n] = size(x);
for i=1:m
  for j=1:n
    y(i,j)=exp(-((((x(i,j) -c)/a) ^2) ^b));
  end
end
endfunction




