function y = bell_2(x, a, b, c)

// BELL_2: Generalized bell-shaped membership function with three
//         parameters a, b, c. (defaults are 1,1, and 0).
//         
//                        Y = BELL_2(X, a, b, c) 
//
//         Returns a matrix y with the same size as X; each element 
//         of Y is a grade of membership. Y=1/(1+(((X - c)/a)^2)^b);
//
//                    See also BELL_1, SIGMOID,TRAPEZE and MF_PANEL.

//       Copyright (c) 1993 Jyh-Shing Roger Jang, U. C. Berkeley
//       jang@eecs.berkeley.edu
//       (Originally Tested on Matlab version 4.0a, HP workstation)
//       Permission is granted to modify and re-distribute this code
//       in any manner as long as this notice is preserved.
//       All standard disclaimers apply.
//       6-28-93.

// FISLAB: Fuzzy Inference Systems toolbox for SCILAB
// Created for MATLAB by 
//	(c) A. Lotfi, University of Queensland (Email: lotfia@s1.elec.uq.oz.au) 13-10-93
// Translated to SCILAB 
//	by G. Ortega, European Space Agency (Email: gortega@estec.esa.nl) 25-07-96
// The program has been tested on SCILAB version 2.2, PC Pentium, runing Linux 1.3.30

// ANFISLAB: Toolbox de ANFIS (ADAPTATIVE-NETWORK-BASED-FUZZY INFERENCE SYSTEM) para SCILAB
// Creado Por Andres G. Avendao Cabezas., Universidad Central de Venezuela (andrewg.avendano@gmail.com),
// Agosto de 2009, con adaptaciones del codigo ANFIS de dominio publico de Jyh-shing Roger Jang
// (http://www.cs.nthu.edu.tw/~jang/publication.htm) y FISLAB de G. Ortega.
// Este programa fue probado en SCILAB version 5.1.1, PC Intel Core(TM) Duo 2,1Ghz, corriendo Linux 2.6.27.7

[nargout,nargin]=argn(0);
if nargin < 4 then, c=0;end,
if nargin < 3 then, b=1;end,
if nargin < 2 then, a=1;end,
[m,n] = size(x);
for i=1:m
  for j=1:n
    f=(x(i,j) - c)		//
    if f==0 then f=0.0001; end, //modificado
    y(i,j)=1/(1+((f/a)^2)^b);   //
  end
end
endfunction